@@ -29,12 +29,12 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginLoader>
-#include <KRun>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 
 #include "filemetadatawidget.h"
 
 K_PLUGIN_FACTORY(BalooFilePropertiesPluginFactory, registerPlugin<BalooFilePropertiesPlugin>();)
-K_EXPORT_PLUGIN(BalooFilePropertiesPlugin("fileshare_propsdlgplugin"))
 
 BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QList<QVariant> &args)
     : KPropertiesDialogPlugin(qobject_cast<KPropertiesDialog *>(parent))
@@ -50,7 +50,9 @@ BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QLis
     auto *metaDataWidget = new Baloo::FileMetaDataWidget();
     metaDataWidget->setItems(properties->items());
     connect(metaDataWidget, &Baloo::FileMetaDataWidget::urlActivated, this, [this](const QUrl &url) {
-        new KRun(url, properties);
+        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, properties));
+        job->start();
     });
 
     containerLayout->addWidget(metaDataWidget);
